==> commons-lang-2.2-src.tar.gz: commons-lang-2.2-src/src/test/org/apache/commons/lang/mutable/MutableTestSuite.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.commons.lang.mutable;

import junit.framework.Test;
import junit.framework.TestSuite;
import junit.textui.TestRunner;

/**
 * JUnit tests.
 * 
 * @version $Id: MutableTestSuite.java 437554 2006-08-28 06:21:41Z bayard $
 */
public class MutableTestSuite {

    public static void main(String[] args) {
        TestRunner.run(suite());
    }

    public static Test suite() {
        final TestSuite suite = new TestSuite();

        suite.addTest(MutableBooleanTest.suite());
        suite.addTest(MutableByteTest.suite());
        suite.addTest(MutableShortTest.suite());
        suite.addTest(MutableIntTest.suite());
        suite.addTest(MutableLongTest.suite());
        suite.addTest(MutableFloatTest.suite());
        suite.addTest(MutableDoubleTest.suite());
        suite.addTest(MutableObjectTest.suite());

        return suite;
    }

    private MutableTestSuite() {
    }

}

==> commons-lang-2.3-src.tar.gz: commons-lang-2.3-src/src/test/org/apache/commons/lang/mutable/MutableTestSuite.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.commons.lang.mutable;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.textui.TestRunner;

/**
 * JUnit tests.
 * 
 * @version $Id: MutableTestSuite.java 475111 2006-11-15 04:11:55Z bayard $
 */
public class MutableTestSuite extends TestCase {

    public static void main(String[] args) {
        TestRunner.run(suite());
    }

    public MutableTestSuite(String name) {
        super(name);
    }

    public static Test suite() {
        final TestSuite suite = new TestSuite();

        suite.addTest(MutableBooleanTest.suite());
        suite.addTest(MutableByteTest.suite());
        suite.addTest(MutableShortTest.suite());
        suite.addTest(MutableIntTest.suite());
        suite.addTest(MutableLongTest.suite());
        suite.addTest(MutableFloatTest.suite());
        suite.addTest(MutableDoubleTest.suite());
        suite.addTest(MutableObjectTest.suite());

        return suite;
    }

}
